function Int = Trapzc(a, b, N, fun)
%Trapzc: Composite Trapezoidal rule.
%   Int = Trapzc(a, b, N, fun) calculates the numerical approximation to
%   the definite integral of a function on N equidistant intervals using
%   the composite trapezoidal quadrature rule.
%   Inputs:
%       a:   Starting point of the integration interval 
%       b:   Ending point of the integration interval (b > a)
%       N:   Number of nodes (INTEGER)
%       fun: Integrand function (either inline, anonymous or defined in a
%            m-file)
%   Output:
% .     Int: Value of the definite integral

%% OPTION 1 (BEST) without loop 

    h = (b - a) / (N - 1); %Define stepsize h
    x = linspace(a, b, N); %Vector of the nodes
    f = fun(x); %function evaluated at the nodes
    f([1, end]) = f([1, end]) / 2;
    Int = h * sum(f);

%% OPTION 2 w/ loop
%     h = (b - a) / (N - 1); %Define stepsize h
%     x = linspace(a, b, N); %Vector of the nodes
%     Int = 0;
%     for i=1:N-2
%         Int = Int + h * fun(x(i)); %Sum over internal nodes
%     end
%     Int = Int + h / 2 * (fun(a) + fun(b));
%% OPTION 2bis
%     h = (b - a) / (N - 1); %Define stepsize h
%     Int = 0;
%     for i=1:N-2
%         Int = Int + h * fun(a + i * h); %Sum over internal nodes
%     end
%     Int = Int + h / 2 * (fun(a) + fun(b));
end