function Int = Midpointc(a, b, N, fun)
%Midpointc: Composite Midpoint rule.
%   Int = Midpointc(a, b, N, fun) calculates the numerical approximation to
%   the definite integral of a function on N equidistant intervals using
%   the composite midpoint quadrature rule.
%   Inputs:
%       a:   Starting point of the integration interval 
%       b:   Ending point of the integration interval (b > a)
%       N:   Number of discretization intervals (INTEGER)
%       fun: Integrand function (either inline, anonymous or defined in a
%            m-file)
%   Output:
% .     Int: Value of the definite integral

    h = (b - a) / N; %Define stepsize h
    x = linspace(a + h/2, b - h/2, N); %Vector of the midpoints
    f = fun(x); %function evaluated at the midpoints
    Int = h * sum(f);







end