function Int = Simpsonc(a, b, N, fun)
%Simpsonc: Composite Simpson rule.
%   Int = Simpsonc(a, b, N, fun) calculates the numerical approximation to
%   the definite integral of a function on N equidistant intervals using
%   the composite Simpson quadrature rule.
%   Inputs:
%       a:   Starting point of the integration interval 
%       b:   Ending point of the integration interval (b > a)
%       N:   Number of discretization intervals (INTEGER)
%       fun: Integrand function (either inline, anonymous or defined in a
%            m-file)
%   Output:
% .     Int: Value of the definite integral

    h = (b - a) / N; %Define stepsize h
    x = linspace(a, b, N + 1); %Vector of the nodes
    f = fun(x);
    f(2:end-1) = 2 * f(2:end-1);
    Int = h * sum(f) / 6;
    
    x = linspace(a + h/2, b - h/2, N); %Vector of midpoints
    f = fun(x);
    Int = Int + 2 * h * sum(f) / 3;


end