function Int = Trapzc(a, b, N, fun)
%Trapzc: Composite Trapezoidal rule.
%   Int = Trapzc(a, b, N, fun) calculates the numerical approximation to
%   the definite integral of a function on N equidistant intervals using
%   the composite trapezoidal quadrature rule.
%   Inputs:
%       a:   Starting point of the integration interval 
%       b:   Ending point of the integration interval (b > a)
%       N:   Number of discretization intervals (INTEGER)
%       fun: Integrand function (either inline, anonymous or defined in a
%            m-file)
%   Output:
% .     Int: Value of the definite integral

    h = (b - a) / N; %Define stepsize h
    x = linspace(a, b, N + 1); %Vector of the nodes
    f = fun(x); %function evaluated at the nodes
    f([1, end]) = f([1, end]) / 2;
    Int = h * sum(f);


end