% Statistical and Numerical Methods for Chemical Engineers 2022
% Exercise 3, assignment 2
clear all
close all
clc

% Definition of function to be integrated
f = @(x)exp(x);

% Definition of integration constants
a = -2;
b = 2;

% Analytical solution of integral
A_an = f(b)-f(a); %int(exp(x)) = exp(x)

% 1.1 Discretization
N = round(logspace(1,5,100)./2);
h = (b - a) ./ N;

% Initialization of vectors for 4 relative errors with the 4 methods
E1 = zeros(1,length(N));
E2 = zeros(1,length(N));
E3 = zeros(1,length(N));

% 1.2 Determination of error
for i = 1:length(N)
    E1(i) = abs(Midpointc(a, b, N(i), f) - A_an) / A_an;
    E2(i) = abs(Trapzc(a, b, N(i), f) - A_an) / A_an;
    E3(i) = abs(Simpsonc(a, b, N(i), f) - A_an) / A_an;
end

% 1.3 Visualization in double-logarithmic plot
figure
loglog(h,E1,'r-x')
hold on
loglog(h,E2,'b-o')
hold on
loglog(h,E3,'k-o')
legend('Midpoint','Trapezoidal','Simpson','location','best')
xlabel('step size')
ylabel('relative error')

% The round-errors caused by very small h are a result of the machine
% precision and the way how intermediate results are saved when processing
% calculations. The actual results shall not be biased by this behavior.

% 1.4b Fitting to determine slope
c1 = polyfit(log(h),log(E1),1);
c2 = polyfit(log(h),log(E2),1);
c3 = polyfit(log(h(h>1e-2)),log(E3(h>1e-2)),1); %We fit only in the range above the appearance of cut off error

% Degree of exactness q represents the order of a polynomical, which is
% approximated exactly. Even degree interpolation polynomials get one degree of exactness
% for free. Midpoint (polynomial order = 0, even) -> q = 1, 
% Trapezoidal (polynomial order = 1, odd) -> q = 1
% Simpson (polynomial order = 2, even) -> q = 3
% Convergence order / order of accuracy: s = q+1 (slope in plot)

% 1.5 Output
fprintf('The convergence orders of the three methods are\n%+1.1g, %+1.1g, %+1.1g', c1(1),c2(1),c3(1))

% 1.6 Write to file
outputfile = fopen('outputfile.txt','w');
fprintf(outputfile, 'The convergence orders of the three methods are\n%+1.1g, %+1.1g, %+1.1g', c1(1),c2(1),c3(1));
fclose(outputfile);



